==> aws-cdk-scala_2.13-0.13.0-sources.jar: io/burkard/cdk/services/appflow/cfnConnectorProfile/ConnectorProfileCredentialsProperty.scala <==
package io.burkard.cdk.services.appflow.cfnConnectorProfile

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ConnectorProfileCredentialsProperty {

  def apply(
    amplitude: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.AmplitudeConnectorProfileCredentialsProperty] = None,
    serviceNow: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.ServiceNowConnectorProfileCredentialsProperty] = None,
    zendesk: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.ZendeskConnectorProfileCredentialsProperty] = None,
    singular: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SingularConnectorProfileCredentialsProperty] = None,
    datadog: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.DatadogConnectorProfileCredentialsProperty] = None,
    trendmicro: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.TrendmicroConnectorProfileCredentialsProperty] = None,
    sapoData: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SAPODataConnectorProfileCredentialsProperty] = None,
    slack: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SlackConnectorProfileCredentialsProperty] = None,
    googleAnalytics: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.GoogleAnalyticsConnectorProfileCredentialsProperty] = None,
    marketo: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.MarketoConnectorProfileCredentialsProperty] = None,
    veeva: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.VeevaConnectorProfileCredentialsProperty] = None,
    dynatrace: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.DynatraceConnectorProfileCredentialsProperty] = None,
    inforNexus: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.InforNexusConnectorProfileCredentialsProperty] = None,
    redshift: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.RedshiftConnectorProfileCredentialsProperty] = None,
    salesforce: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SalesforceConnectorProfileCredentialsProperty] = None,
    snowflake: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SnowflakeConnectorProfileCredentialsProperty] = None
  ): software.amazon.awscdk.services.appflow.CfnConnectorProfile.ConnectorProfileCredentialsProperty =
    (new software.amazon.awscdk.services.appflow.CfnConnectorProfile.ConnectorProfileCredentialsProperty.Builder)
      .amplitude(amplitude.orNull)
      .serviceNow(serviceNow.orNull)
      .zendesk(zendesk.orNull)
      .singular(singular.orNull)
      .datadog(datadog.orNull)
      .trendmicro(trendmicro.orNull)
      .sapoData(sapoData.orNull)
      .slack(slack.orNull)
      .googleAnalytics(googleAnalytics.orNull)
      .marketo(marketo.orNull)
      .veeva(veeva.orNull)
      .dynatrace(dynatrace.orNull)
      .inforNexus(inforNexus.orNull)
      .redshift(redshift.orNull)
      .salesforce(salesforce.orNull)
      .snowflake(snowflake.orNull)
      .build()
}

==> aws-cdk-scala_3-0.22.0-sources.jar: io/burkard/cdk/services/appflow/cfnConnectorProfile/ConnectorProfileCredentialsProperty.scala <==
package io.burkard.cdk.services.appflow.cfnConnectorProfile

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ConnectorProfileCredentialsProperty {

  def apply(
    amplitude: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.AmplitudeConnectorProfileCredentialsProperty] = None,
    customConnector: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.CustomConnectorProfileCredentialsProperty] = None,
    serviceNow: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.ServiceNowConnectorProfileCredentialsProperty] = None,
    zendesk: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.ZendeskConnectorProfileCredentialsProperty] = None,
    singular: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SingularConnectorProfileCredentialsProperty] = None,
    datadog: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.DatadogConnectorProfileCredentialsProperty] = None,
    trendmicro: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.TrendmicroConnectorProfileCredentialsProperty] = None,
    sapoData: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SAPODataConnectorProfileCredentialsProperty] = None,
    slack: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SlackConnectorProfileCredentialsProperty] = None,
    googleAnalytics: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.GoogleAnalyticsConnectorProfileCredentialsProperty] = None,
    marketo: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.MarketoConnectorProfileCredentialsProperty] = None,
    veeva: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.VeevaConnectorProfileCredentialsProperty] = None,
    dynatrace: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.DynatraceConnectorProfileCredentialsProperty] = None,
    inforNexus: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.InforNexusConnectorProfileCredentialsProperty] = None,
    redshift: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.RedshiftConnectorProfileCredentialsProperty] = None,
    salesforce: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SalesforceConnectorProfileCredentialsProperty] = None,
    snowflake: Option[software.amazon.awscdk.services.appflow.CfnConnectorProfile.SnowflakeConnectorProfileCredentialsProperty] = None
  ): software.amazon.awscdk.services.appflow.CfnConnectorProfile.ConnectorProfileCredentialsProperty =
    (new software.amazon.awscdk.services.appflow.CfnConnectorProfile.ConnectorProfileCredentialsProperty.Builder)
      .amplitude(amplitude.orNull)
      .customConnector(customConnector.orNull)
      .serviceNow(serviceNow.orNull)
      .zendesk(zendesk.orNull)
      .singular(singular.orNull)
      .datadog(datadog.orNull)
      .trendmicro(trendmicro.orNull)
      .sapoData(sapoData.orNull)
      .slack(slack.orNull)
      .googleAnalytics(googleAnalytics.orNull)
      .marketo(marketo.orNull)
      .veeva(veeva.orNull)
      .dynatrace(dynatrace.orNull)
      .inforNexus(inforNexus.orNull)
      .redshift(redshift.orNull)
      .salesforce(salesforce.orNull)
      .snowflake(snowflake.orNull)
      .build()
}
